==> feijoa-0.1.7.tar.gz: feijoa-0.1.7/feijoa/utils/mixins.py <==
# MIT License
#
# Copyright (c) 2021-2022 Templin Konstantin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Different mixins module."""
from abc import ABCMeta
from abc import abstractmethod


class Observer(metaclass=ABCMeta):
    """
    The Observer interface declares the
    update method, used by subjects.
    """

    @abstractmethod
    def update(self, event, subject, *args, **kwargs):
        """
        Receive update from subject.

                Args:
                    event:
                        Type of event.
                    subject:
                        Subject of notification.

                Returns:
                    None

                Raises:
                    AnyError: If anything bad happens.

        """

        pass


class Subject(metaclass=ABCMeta):
    """
    The Subject interface declares a set
    of methods for managing subscribers.
    """

    @abstractmethod
    def attach(self, observer: Observer) -> None:
        """
        Attach an observer to the subject.
        """
        pass

    @abstractmethod
    def detach(self, observer: Observer) -> None:
        """
        Detach an observer from the subject.
        """
        pass

    @abstractmethod
    def notify(self, event, *args, **kwargs) -> None:
        """
        Notify all observers about an event.
        """
        pass

==> feijoa-0.1.11.tar.gz: feijoa-0.1.11/feijoa/utils/mixins.py <==
# MIT License
#
# Copyright (c) 2021-2022 Templin Konstantin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Different mixins module."""
from abc import ABCMeta, abstractmethod


class Observer(metaclass=ABCMeta):
    """
    The Observer interface declares the
    update method, used by subjects.
    """

    @abstractmethod
    def update(self, event, subject, *args, **kwargs):
        """
        Receive update from subject.

                Args:
                    event:
                        Type of event.
                    subject:
                        Subject of notification.

                Returns:
                    None

                Raises:
                    AnyError: If anything bad happens.

        """

        pass


class Subject(metaclass=ABCMeta):
    """
    The Subject interface declares a set
    of methods for managing subscribers.
    """

    @abstractmethod
    def attach(self, observer: Observer) -> None:
        """
        Attach an observer to the subject.
        """
        pass

    @abstractmethod
    def detach(self, observer: Observer) -> None:
        """
        Detach an observer from the subject.
        """
        pass

    @abstractmethod
    def notify(self, event, *args, **kwargs) -> None:
        """
        Notify all observers about an event.
        """
        pass
